@@ -36,6 +36,7 @@
 #include <functional>
 #include <sstream>
 #include <string>
+#include "debug_sync.h"
 
 /* We don't need PSI instrumentation for regex mutex, however
    Regex class has its constructor compiled conditionally.
@@ -105,7 +106,7 @@ static Regex sst_method_allowed_chars_regex;
 
 
 extern const char wsrep_defaults_file[];
-extern const char wsrep_defaults_group_suffix[];
+extern const char *wsrep_defaults_group_suffix;
 
 #define WSREP_SST_OPT_ROLE     "--role"
 #define WSREP_SST_OPT_ADDR     "--address"
@@ -962,6 +963,17 @@ ssize_t wsrep_sst_prepare (void** msg, THD* thd)
 
     if (host_len < addr_len)
     {
+      /* ip_buf is 256 bytes, wsrep_node_address is <ip_address>[:port]
+         so for ipv6 host part is at most 45 characters (IPv4-mapped IPv6).
+         Host part will entirely fit into ip_buf leaving space for trailing zero. */
+      if (unlikely(host_len >= ip_max)) {
+        WSREP_ERROR("Could not prepare state transfer request: "
+                    "Host IP does not fit into temporary buffer. "
+                    "wsrep_node_address: %s, host_len: %lu",
+                    wsrep_node_address, host_len);
+        if (thd) delete thd;
+        unireg_abort(1);
+      }
       strncpy (ip_buf, wsrep_node_address, host_len);
       ip_buf[host_len]= '\0';
       addr_in= ip_buf;
@@ -1187,6 +1199,19 @@ static int run_sql_command(THD *thd, const char *query)
   return 0;
 }
 
+static void sst_disallow_writes (THD* thd, bool yes)
+{
+  char query_str[64] = { 0, };
+  ssize_t const query_max = sizeof(query_str) - 1;
+  snprintf (query_str, query_max, "SET GLOBAL innodb_disallow_writes=%d",
+            yes ? 1 : 0);
+
+  if (run_sql_command(thd, query_str))
+  {
+    WSREP_ERROR("Failed to disallow InnoDB writes");
+  }
+}
+
 static int sst_flush_tables(THD* thd)
 {
   WSREP_INFO("Flushing tables for SST...");
@@ -1212,6 +1237,10 @@ static int sst_flush_tables(THD* thd)
   else
   {
     WSREP_INFO("Table flushing completed.");
+
+    /* disable further disk IO */
+    sst_disallow_writes(thd, true);
+
     const char base_name[]= "tables_flushed";
     ssize_t const full_len= strlen(mysql_real_data_home) + strlen(base_name)+2;
     char *real_name= static_cast<char *>(alloca(full_len));
@@ -1243,19 +1272,6 @@ static int sst_flush_tables(THD* thd)
   return err;
 }
 
-static void sst_disallow_writes (THD* thd, bool yes)
-{
-  char query_str[64] = { 0, };
-  ssize_t const query_max = sizeof(query_str) - 1;
-  snprintf (query_str, query_max, "SET GLOBAL innodb_disallow_writes=%d",
-            yes ? 1 : 0);
-
-  if (run_sql_command(thd, query_str))
-  {
-    WSREP_ERROR("Failed to disallow InnoDB writes");
-  }
-}
-
 static void* sst_donor_thread (void* a)
 {
   sst_thread_arg* arg= (sst_thread_arg*)a;
@@ -1311,8 +1327,16 @@ wait_signal:
         err= sst_flush_tables (thd.ptr);
         if (!err)
         {
-          sst_disallow_writes (thd.ptr, true);
           locked= true;
+          DBUG_EXECUTE_IF("sync.wsrep_donor_state",
+                  {
+                    const char act[]=
+                      "now "
+                      "SIGNAL sync.wsrep_donor_state_reached "
+                      "WAIT_FOR signal.wsrep_donor_state";
+                    assert(!debug_sync_set_action(thd.ptr,
+                                                  STRING_WITH_LEN(act)));
+                  };);
           goto wait_signal;
         }
       }
@@ -1392,8 +1416,6 @@ skip_clear_pointer:
   return NULL;
 }
 
-
-
 static int sst_donate_other (const char*   method,
                              const char*   addr,
                              const char*   uuid,
